Summary:        JPEG image codec that uses SIMD instructions to accelerate JPEG compression and decompression 
Name:           libjpeg-turbo
Version:        2.1.3
Release:        3%{?dist}
License:        IJG
URL:            https://libjpeg-turbo.org/
Source0:        https://sourceforge.net/projects/libjpeg-turbo/files/%{version}/%{name}-%{version}.tar.gz
Patch3000:      libjpeg-turbo-CET.patch

BuildRequires:  gcc cmake libtool nasm
Provides:       libjpeg

%description
libjpeg-turbo is a JPEG image codec that uses SIMD instructions (MMX, SSE2, NEON, AltiVec) 
to accelerate baseline JPEG compression and decompression on x86, x86-64, ARM, and PowerPC systems.
On such systems, libjpeg-turbo is generally 2-6x as fast as libjpeg, all else being equal.
On other types of systems, libjpeg-turbo can still outperform libjpeg by a significant amount,
by virtue of its highly-optimized Huffman coding routines. In many cases, the performance of
libjpeg-turbo rivals that of proprietary high-speed JPEG codecs.

libjpeg-turbo implements both the traditional libjpeg API as well as the less powerful but
more straightforward TurboJPEG API.


%package utils
Summary:        Utilities for manipulating JPEG images
Requires:       libjpeg-turbo = %{version}-%{release}

%description utils
The package contains simple client programs for accessing the libjpeg functions.
It contains cjpeg, djpeg, jpegtran, rdjpgcom and wrjpgcom:
1.Cjpeg compresses an image file into JPEG format.
2.Djpeg decompresses a JPEG file into a regular image file. 
3.Jpegtran can perform various useful transformations on JPEG files.
4.Rdjpgcom displays any text comments included in a JPEG file.
5.Wrjpgcom inserts text comments into a JPEG file.


%package -n turbojpeg
Summary:        TurboJPEG library

%description -n turbojpeg
TurboJPEG shared library.


%package -n turbojpeg-devel
Summary:        Headers for the TurboJPEG library
Requires:       turbojpeg = %{version}-%{release}

%description -n turbojpeg-devel
Header files for developing programs using the TurboJPEG library.


%package devel
Summary:        Headers for the libjpeg-turbo library
Requires:       libjpeg-turbo = %{version}-%{release}
Provides:       libjpeg-devel = %{version}-%{release}

%description devel
Header files for developing programs using the libjpeg-turbo library.


%prep
%autosetup -p1


%build
%ifarch x86_64
export LDFLAGS="$RPM_LD_FLAGS -Wl,-z,ibt -Wl,-z,shstk"
%endif

%{cmake} -DCMAKE_SKIP_RPATH:BOOL=YES \
         -DCMAKE_SKIP_INSTALL_RPATH:BOOL=YES \
         -DENABLE_STATIC:BOOL=NO

%cmake_build


%install
%cmake_install
find %{buildroot} -name "*.la" -delete
rm -rf %{buildroot}%{_pkgdocdir}
chmod -x README.md


%check
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
%ctest


%files
%license LICENSE.md
%doc README.md README.ijg ChangeLog.md
%{_libdir}/libjpeg.so.62*

%files utils
%doc usage.txt wizard.txt
%{_bindir}/*
%{_mandir}/man1/*

%files -n turbojpeg
%license LICENSE.md
%doc README.md README.ijg ChangeLog.md
%{_libdir}/libturbojpeg.so.0*

%files -n turbojpeg-devel
%doc tjexample.c
%{_includedir}/turbojpeg.h
%{_libdir}/libturbojpeg.so
%{_libdir}/pkgconfig/libturbojpeg.pc

%files devel
%doc coderules.txt jconfig.txt libjpeg.txt structure.txt example.txt
%{_includedir}/*.h
%exclude %{_includedir}/turbojpeg.h
%{_libdir}/libjpeg.so
%{_libdir}/pkgconfig/libjpeg.pc
%{_libdir}/cmake/%{name}/%{name}*.cmake


%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.1.3-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.1.3-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Jul 21 2022 rockerzhu <rockerzhu@tencent.com> - 2.1.3-1
- Initial build
